@@ -31,7 +31,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'sort' => [ qw(NO_SORT SORT_NATURAL SORT_PATH) ] );
 our @EXPORT_OK = qw(NO_SORT SORT_NATURAL SORT_PATH);
     
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 =head1 NAME
 
@@ -191,7 +191,7 @@ Whether or not this setting is mandatory.
 =item default => I<VALUE>
 
 Default value for the setting. This value will be assigned if that particular
-statement is not explicilty used in the configuration file. If I<VALUE>
+statement is not explicitly used in the configuration file. If I<VALUE>
 is a CODE reference, it will be invoked as a method each time the value is
 accessed.
 
@@ -218,7 +218,7 @@ called as
     $self->$coderef($node, @path)
 
 where $node is the B<Config::AST::Node::Value> object (use
-B<$vref-E<gt>value>, to obtain the actual value), and B<@path> is its patname.
+B<$vref-E<gt>value>, to obtain the actual value), and B<@path> is its pathname.
     
 =item check => I<coderef>
 
@@ -719,10 +719,12 @@ sub AUTOLOAD {
     return Config::AST::Follow->new($self->tree, $self->lexicon)->${\$m};
 }
 
+sub DESTROY { }
+
 =head1 CONSTRUCTING THE SYNTAX TREE
 
 The methods described in this section are intended for use by the parser
-implementors. They should be called from the implementation of the B<parse>
+implementers. They should be called from the implementation of the B<parse>
 method in order to construct the tree.    
     
 =cut
@@ -954,7 +956,7 @@ sub unset {
     }
 }    
 
-=head1 AUXILARY METHODS
+=head1 AUXILIARY METHODS
 
 =head2 @array = $cfg->names_of(@path)
 
